@@ -49,7 +49,9 @@ __all__ = (
     "InfrastructureConfigurationSummaryTypeDef",
     "InfrastructureConfigurationTypeDef",
     "InstanceBlockDeviceMappingTypeDef",
+    "InstanceConfigurationTypeDef",
     "LaunchPermissionConfigurationTypeDef",
+    "LaunchTemplateConfigurationTypeDef",
     "LoggingTypeDef",
     "OutputResourcesTypeDef",
     "S3LogsTypeDef",
@@ -232,6 +234,7 @@ ContainerRecipeTypeDef = TypedDict(
         "owner": str,
         "version": str,
         "components": List["ComponentConfigurationTypeDef"],
+        "instanceConfiguration": "InstanceConfigurationTypeDef",
         "dockerfileTemplateData": str,
         "kmsKeyId": str,
         "encrypted": bool,
@@ -293,6 +296,7 @@ _OptionalDistributionTypeDef = TypedDict(
         "amiDistributionConfiguration": "AmiDistributionConfigurationTypeDef",
         "containerDistributionConfiguration": "ContainerDistributionConfigurationTypeDef",
         "licenseConfigurationArns": List[str],
+        "launchTemplateConfigurations": List["LaunchTemplateConfigurationTypeDef"],
     },
     total=False,
 )
@@ -512,12 +516,34 @@ InstanceBlockDeviceMappingTypeDef = TypedDict(
     total=False,
 )
 
+InstanceConfigurationTypeDef = TypedDict(
+    "InstanceConfigurationTypeDef",
+    {"image": str, "blockDeviceMappings": List["InstanceBlockDeviceMappingTypeDef"]},
+    total=False,
+)
+
 LaunchPermissionConfigurationTypeDef = TypedDict(
     "LaunchPermissionConfigurationTypeDef",
     {"userIds": List[str], "userGroups": List[str]},
     total=False,
 )
 
+_RequiredLaunchTemplateConfigurationTypeDef = TypedDict(
+    "_RequiredLaunchTemplateConfigurationTypeDef", {"launchTemplateId": str}
+)
+_OptionalLaunchTemplateConfigurationTypeDef = TypedDict(
+    "_OptionalLaunchTemplateConfigurationTypeDef",
+    {"accountId": str, "setDefaultVersion": bool},
+    total=False,
+)
+
+
+class LaunchTemplateConfigurationTypeDef(
+    _RequiredLaunchTemplateConfigurationTypeDef, _OptionalLaunchTemplateConfigurationTypeDef
+):
+    pass
+
+
 LoggingTypeDef = TypedDict("LoggingTypeDef", {"s3Logs": "S3LogsTypeDef"}, total=False)
 
 OutputResourcesTypeDef = TypedDict(
